@@ -10,6 +10,7 @@
 #' @return A data.frame representing the adjacency list of the ENA-produced network.
 #' @export
 #' @author Jeffrey D. Allen \email{Jeffrey.Allen@@UTSouthwestern.edu}
+#' @examples
 #' #Load in the sample Protein-Protein-Interaction data that comes with this package.
 #' data(PPI)
 #' set.seed(123)
@@ -19,6 +20,8 @@
 #' 
 #' boot <- bootstrap(sim, "buildGenenet", .9, 10, )
 #' bootMat <- tri2mat(rownames(sim), boot[,3])
+#' @importFrom parallel clusterExport
+#' @importFrom parallel parLapply
 bootstrap <- function(data, fun, sample.percentage=0.7, iterations=150, cluster, truth){
 	if (typeof(fun) != "character"){
 		stop("You must provide the character name of the function you want to bootstrap. For instance, fun=\"buildSpace\"")
@@ -38,8 +41,11 @@ bootstrap <- function(data, fun, sample.percentage=0.7, iterations=150, cluster,
 	toReturn <- getTableAddressing(rownames(data), truth)
 	
 	if (!missing(cluster) && "MPIcluster" %in% class(cluster)){		
-		clusterExport(cluster, c("symmetricize"))
-		result <- clusterApplyLB(cluster, 1:iterations, funWrapper, fun, data, sample.percentage)	
+		# Due to some strange quirk of the depends/imports mess (we import GeneNet
+		# but GeneNet depends on corpcor), we have to export this function from
+		# corpcor than GeneNet relies on. No idea.
+		clusterExport(cluster, c("symmetricize", "pcor.shrink"))
+		result <- parLapply(cluster, 1:iterations, funWrapper, fun, data, sample.percentage)	
 	}
 	else{ 
 		result <- lapply(1:iterations, funWrapper, fun, data, sample.percentage)		
